pub struct RtmpHandler<RW: AsyncRead + AsyncWrite + Unpin>(/* private fields */);Expand description
The default RTMP handler.
This handles the raw RTMP by well-known communication steps. That is, this performs just following steps.
With publishers
- Checks the application name from the
Connectcommand. - Checks the topic path from the
ReleaseStream/FcPublishcommand. - Provides a message ID when receives the
CreateStreamcommand. - Checks publication informations from the
Publishcommand. - Then receives FLV media data.
If some error occurs in any step, sends commands which are FcUnpublish and DeleteStream to its client, then terminates its connection.
These perform to delete the topic path and a message ID from its context.
However also these can be sent from clients.
With subscribers
- Checks the application name from the
Connectcommand. - Checks partner’s bandwidsth from the
WindowAcknowledgementSizemessage. - Provides a message ID when receives the
CreateStreamcommand. - Checks the topic path from the
FcSubscribecommand. - Handles one of additional commands either
GetStreamLengthorSetPlaylist. - Checkes subscription informaitons from
Playcommand/ - The sends FLV media data.
In Both sides, if receiving data size exceeds server’s bandwidth, this reports its thing via the Acknowledgement message to its client.
Examples
use std::marker::PhantomData;
use sheave_core::handlers::{
RtmpContext,
VecStream
};
use sheave_server::{
Server,
handlers::RtmpHandler,
};
let stream = VecStream::default();
let rtmp_context = RtmpContext::default();
let server = Server::new(stream, rtmp_context, PhantomData::<RtmpHandler<VecStream>>);Trait Implementations
Sourceimpl<RW: AsyncRead + AsyncWrite + Unpin> AsyncHandler for RtmpHandler<RW>
impl<RW: AsyncRead + AsyncWrite + Unpin> AsyncHandler for RtmpHandler<RW>
fn poll_handle( self: Pin<&mut Self>, cx: &mut FutureContext<'_>, rtmp_context: &mut RtmpContext, ) -> Poll<IOResult<()>>
Sourceimpl<RW: AsyncRead + AsyncWrite + Unpin> HandlerConstructor<StreamWrapper<RW>> for RtmpHandler<RW>
impl<RW: AsyncRead + AsyncWrite + Unpin> HandlerConstructor<StreamWrapper<RW>> for RtmpHandler<RW>
fn new(stream: Arc<StreamWrapper<RW>>) -> Self